#[repr(C)]pub struct WINDIVERT_DATA_FLOW {
pub endpoint_id: u64,
pub parent_endpoint_id: u64,
pub process_id: u32,
pub local_addr: [u32; 4],
pub remote_addr: [u32; 4],
pub local_port: u16,
pub remote_port: u16,
pub protocol: u8,
}Expand description
Represents the associated data recieved using WinDivertLayer::Flow
Fields
endpoint_id: u64The endpoint ID of the flow.
parent_endpoint_id: u64The parent endpoint ID of the flow.
process_id: u32The id of the process associated with the flow.
local_addr: [u32; 4]The local address associated with the socket.
For IPv4, this field will contain IPv4-mapped IPv6 addresses, e.g. the IPv4 address X.Y.Z.W will be represented by ::ffff:X.Y.Z.W.
This field can contain a value o zero, since SocketBind and SocketBind events can occur before a connection attempt has been made.
remote_addr: [u32; 4]The remote address associated with the socket.
For IPv4, this field will contain IPv4-mapped IPv6 addresses, e.g. the IPv4 address X.Y.Z.W will be represented by ::ffff:X.Y.Z.W.
This field can contain a value o zero, since SocketBind and SocketBind events can occur before a connection attempt has been made.
local_port: u16The local port associated with the flow.
remote_port: u16The remote port associated with the flow.
protocol: u8The flow protocol.