Module ioctl

Module ioctl 

WinDivert IOCTL types.

This types are not used by this crate but some of them are used by the wrapper crate in order to implement wait variants for recv and recv_ex.

Structs

WINDIVERT_IOCTL_GET_PARAM
WINDIVERT_IOCTL_INITIALIZE
WINDIVERT_IOCTL_RECV
WINDIVERT_IOCTL_SET_PARAM
WINDIVERT_IOCTL_SHUTDOWN
WINDIVERT_IOCTL_STARTUP

Type Aliases

WINDIVERT_IOCTL_SEND

Unions

WINDIVERT_IOCTL